<?php

namespace apexl\Io\modules\formbuilder\includes;

use apexl\Io\modules\formbuilder\includes\formField;

class inputField extends formField
{
    public function __construct($name, $type = 'text')
    {
        parent::__construct($name, 'input', $type);
    }
}
