<?php

namespace apexl\Io\modules\formbuilder\includes;

class linkField extends formField
{
    public function __construct($name)
    {
        parent::__construct($name, 'link');
    }

    public function setLinkType($name)
    {
        $this->field->linkType = $name;
        return $this;
    }

    public function setLinkTitle($name)
    {
        $this->field->linkTitle = $name;
        return $this;
    }
}
